==> pureadmin_0.1.11.orig.tar.gz: pureadmin-0.1.11.orig/src/callbacks.h <==
/* PureAdmin
 * Copyright (C) 2003 Isak Savo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * Callback-functions from the GUI
 *
 * Copyright (C) 2003 Isak Savo
 */

#include <gtk/gtk.h>

gboolean
on_main_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_main_window_destroy                 (GtkObject       *object,
                                        gpointer         user_data);

void
on_button1_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
show_hide_advanced_info                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
menu_callback                          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_tree_activity_cursor_changed        (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_user_info1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_kick_user1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_btn_user_manager_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_dlg_show_users_close                (GtkDialog       *dialog,
                                        gpointer         user_data);

gboolean
dlg_show_users_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_dlg_show_users_destroy_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_treeview_dlg_users_cursor_changed   (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_usr_dlg_btn_edituser_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_removeuser_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_save_changes_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_save_changes_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_adduser_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_change_pw_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_chk_chroot_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_import_users1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_manage_users1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item2_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item3_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_usr_dlg_btn_cancel_changes_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
close_usrman_dialog                    (GtkButton       *button,
                                        gpointer         user_data);

void
menu_import_users                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_quit                              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_preferences                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_srv_startstop                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_user_manager                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_config_server                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_about                             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_help                              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_usrman_delete_event                 (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_new_user_entry_change               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_pwentry_changed                     (GtkEditable     *editable,
                                        gpointer         user_data);

void
optmenu_id_changed                     (GtkOptionMenu   *optionmenu,
                                        gpointer         user_data);

void
on_btn_logview_clear_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_logview_reread_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_browse_homedir_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_browse_fakeroot_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_index1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_introduction1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_main_window1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_usr_dlg_btn_help_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
menu_close_connections                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_close_transfer1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_close_all_user_connections1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_edit_user_information1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_tree_activity_popup_menu            (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_tree_activity_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_tree_users_popup_menu               (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_tree_users_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_popup_close_tx                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_popup_close_all_conns               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_popup_edit_user                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_view_debug_console_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_dlg_debug_delete_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_dlg_debug_destroy_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

==> pureadmin-0.2.2.tar.gz: pureadmin-0.2.2/src/callbacks.h <==
/* PureAdmin
 * Copyright (C) 2003 Isak Savo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * Callback-functions from the GUI
 *
 * Copyright (C) 2003 Isak Savo
 */

#include <gtk/gtk.h>

gboolean
on_main_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_main_window_destroy                 (GtkObject       *object,
                                        gpointer         user_data);

void
on_button1_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
show_hide_advanced_info                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
menu_callback                          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_tree_activity_cursor_changed        (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_user_info1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_kick_user1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_btn_user_manager_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_dlg_show_users_close                (GtkDialog       *dialog,
                                        gpointer         user_data);

gboolean
dlg_show_users_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_treeview_dlg_users_cursor_changed   (GtkTreeView     *treeview,
                                        gpointer         user_data);

void
on_usr_dlg_btn_edituser_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_removeuser_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_save_changes_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_save_changes_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_adduser_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_btn_change_pw_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_usr_dlg_chk_chroot_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_import_users1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_manage_users1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item2_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_item3_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_usr_dlg_btn_cancel_changes_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
close_usrman_dialog                    (GtkButton       *button,
                                        gpointer         user_data);

void
menu_import_users                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_quit                              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_preferences                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_srv_startstop                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_user_manager                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_config_server                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_about                             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
menu_help                              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_usrman_delete_event                 (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_new_user_entry_change               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_pwentry_changed                     (GtkEditable     *editable,
                                        gpointer         user_data);

void
optmenu_id_changed                     (GtkOptionMenu   *optionmenu,
                                        gpointer         user_data);

void
on_btn_logview_clear_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_logview_reread_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_browse_homedir_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_browse_fakeroot_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_index1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_introduction1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_main_window1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_usr_dlg_btn_help_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
menu_close_connections                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_close_transfer1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_close_all_user_connections1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_edit_user_information1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_tree_activity_popup_menu            (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_tree_activity_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_tree_users_popup_menu               (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_tree_users_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_popup_close_tx                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_popup_close_all_conns               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_popup_edit_user                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_view_debug_console_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_dlg_debug_delete_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_dlg_debug_destroy_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_usrman_delete_event                 (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
mainwindow_keypress                    (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_main_window_notify                  (GObject         *gobject,
                                        GParamSpec      *arg1,
                                        gpointer         user_data);

gboolean
mainwin_keypress                       (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_system_encoding1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
